.. _whatsnew_0702:

v.0.7.2 (March 16, 2012)
---------------------------

{{ header }}


This release targets bugs in 0.7.1, and adds a few minor features.

New features
~~~~~~~~~~~~

  - Add additional tie-breaking methods in DataFrame.rank (:issue:`874`)
  - Add ascending parameter to rank in Series, DataFrame (:issue:`875`)
  - Add coerce_float option to DataFrame.from_records (:issue:`893`)
  - Add sort_columns parameter to allow unsorted plots (:issue:`918`)
  - Enable column access via attributes on GroupBy (:issue:`882`)
  - Can pass dict of values to DataFrame.fillna (:issue:`661`)
  - Can select multiple hierarchical groups by passing list of values in .ix
    (:issue:`134`)
  - Add ``axis`` option to DataFrame.fillna (:issue:`174`)
  - Add level keyword to ``drop`` for dropping values from a level (:issue:`159`)

Performance improvements
~~~~~~~~~~~~~~~~~~~~~~~~

  - Use khash for Series.value_counts, add raw function to algorithms.py (:issue:`861`)
  - Intercept __builtin__.sum in groupby (:issue:`885`)



.. _whatsnew_0.7.2.contributors:

Contributors
~~~~~~~~~~~~

.. contributors:: v0.7.1..v0.7.2
